"""Module for neural network board evaluators."""

from .neural_net_board_eval_args import NeuralNetBoardEvalArgs
from .nn_state_evaluator import NNBWStateEvaluator

__all__ = ["NNBWStateEvaluator", "NeuralNetBoardEvalArgs"]
